@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import locale
 import threading
@@ -48,9 +52,9 @@ class Task(object):
             self.owner.send_info("%s cancelled" % self.label)
             self.set_aborted()
             return
-        except Exception, e:
+        except Exception as e:
             if not isinstance(self, ThreadedTask):
-                print
+                print()
                 import traceback
                 traceback.print_exc()
 
@@ -153,8 +157,8 @@ class ThreadedTask(Task):
             self.owner.send_info("%s cancelled" % self.label)
             mforms.Utilities.perform_from_main_thread(self.set_aborted, False)
             return
-        except Exception, exc:
-            print
+        except Exception as exc:
+            print()
             import traceback
             traceback.print_exc()
             grt.log_error("Wizard", "Thread '%s' failed: %s\n" % (self.label, exc))
@@ -368,7 +372,7 @@ class ProgressMainView(WizardPage):
 
             try:
                 task.run()
-            except Exception, exc:
+            except Exception as exc:
                 self.send_error("Exception in task '%s': %r\n" % (task.label, exc))
                 self._status_label.set_text("%s" % self.format_exception_text(exc))
                 self._failed()
@@ -644,7 +648,7 @@ class ProgressMainView(WizardPage):
         self.send_progress(0, 'Data copy starting')
         total = 0
         table_count = len (self._working_set);
-        for task in self._working_set.values():
+        for task in list(self._working_set.values()):
             total += task.get("row_count", 0)
             self.create_transfer_log(task["target_table_object"])
 
@@ -665,7 +669,7 @@ class ProgressMainView(WizardPage):
                 
             self.send_info("Data copy results:")
             fully_copied = 0
-            for task in self._working_set.values():
+            for task in list(self._working_set.values()):
                 info = succeeded_tasks.get(task["target_schema"]+"."+task["target_table"], None)
                 row_count = task.get("row_count", 0)
                 if info:
